summaryrefslogtreecommitdiffstats
path: root/quanta/treeviews/structtreeview.h
diff options
context:
space:
mode:
Diffstat (limited to 'quanta/treeviews/structtreeview.h')
-rw-r--r--quanta/treeviews/structtreeview.h64
1 files changed, 32 insertions, 32 deletions
diff --git a/quanta/treeviews/structtreeview.h b/quanta/treeviews/structtreeview.h
index 4f59e7d3..2d87f038 100644
--- a/quanta/treeviews/structtreeview.h
+++ b/quanta/treeviews/structtreeview.h
@@ -18,8 +18,8 @@
#ifndef STRUCTTREEVIEW_H
#define STRUCTTREEVIEW_H
-#include <qmap.h>
-#include <qvaluelist.h>
+#include <tqmap.h>
+#include <tqvaluelist.h>
#include <klistview.h>
@@ -48,7 +48,7 @@ public:
* the parameters are only used at the first call to create the class
*
*/
- static StructTreeView* const ref(QWidget *parent = 0L, const char *name = 0L)
+ static StructTreeView* const ref(TQWidget *parent = 0L, const char *name = 0L)
{
static StructTreeView *m_ref;
if (!m_ref) m_ref = new StructTreeView (parent, name);
@@ -64,8 +64,8 @@ public:
void showTagAtPos(Node *node);
/** Delete the items */
void deleteList(bool groupOnly);
- void setParsingDTDs(const QStringList &parsingDTDList);
- void showMessage(const QString& message);
+ void setParsingDTDs(const TQStringList &parsingDTDList);
+ void showMessage(const TQString& message);
bool useOpenLevelSetting;
@@ -73,13 +73,13 @@ public:
public slots: // Public slots
/** repaint document structure */
void slotReparse(Document *w, Node* node, int openLevel = 3,bool groupOnly=false);
- void slotMouseClicked(int button, QListViewItem*, const QPoint&, int);
- void slotDoubleClicked( QListViewItem * );
+ void slotMouseClicked(int button, TQListViewItem*, const TQPoint&, int);
+ void slotDoubleClicked( TQListViewItem * );
// slots for RBM menu
void slotReparseMenuItem();
void slotSelectTag();
- void slotGotoTag( QListViewItem *item );
+ void slotGotoTag( TQListViewItem *item );
void slotGotoClosingTag();
/** Recursively open the tree and all its subtrees */
void slotOpenSubTree();
@@ -87,9 +87,9 @@ public slots: // Public slots
void slotCloseSubTree();
void changeFollowCursor() { setFollowCursor(!followCursorFlag); }
/** No descriptions */
- void slotCollapsed(QListViewItem *item);
+ void slotCollapsed(TQListViewItem *item);
/** No descriptions */
- void slotExpanded(QListViewItem *);
+ void slotExpanded(TQListViewItem *);
void slotOpenFile();
void slotNodeTreeChanged();
void slotRemoveTags();
@@ -99,11 +99,11 @@ signals:
void selectTagArea(Node* node);
void selectArea(int col1, int row1, int col2, int row2 );
void needReparse();
- void onTag( const QString &tag );
- void showGroupsForDTEP(const QString& dtep, bool show);
+ void onTag( const TQString &tag );
+ void showGroupsForDTEP(const TQString& dtep, bool show);
void openFile(const KURL&);
void openImage(const KURL&);
- void showProblemMessage(const QString&);
+ void showProblemMessage(const TQString&);
void clearProblemOutput();
private:
@@ -112,17 +112,17 @@ private:
* If you need the class use StructTreeView::ref() for
* construction and reference
*/
- StructTreeView(QWidget *parent=0, const char *name=0);
+ StructTreeView(TQWidget *parent=0, const char *name=0);
/** builds the structure tree */
void buildTree(Node *baseNode, int openLevel, bool groupOnly);
/** Do the recursive opening or closing of the trees */
- void setOpenSubTree(QListViewItem *it, bool open);
+ void setOpenSubTree(TQListViewItem *it, bool open);
/** Make ctrl have the same behavior has shift */
void setContiguousSelectedItems();
- void copySelectedItems(QListViewItem* parent, QListViewItem* after);
- void moveSelectedItems(QListViewItem* parent, QListViewItem* after);
+ void copySelectedItems(TQListViewItem* parent, TQListViewItem* after);
+ void moveSelectedItems(TQListViewItem* parent, TQListViewItem* after);
private:
@@ -134,43 +134,43 @@ private:
KPopupMenu *dtdMenu;
StructTreeTag *lastTag;
KConfig *config;
- QStringList dtdList;
- QValueList<const DTDStruct*> m_parsingDTDList;
+ TQStringList dtdList;
+ TQValueList<const DTDStruct*> m_parsingDTDList;
int openFileMenuId;
- QMap<QString, uint> groupIds;
+ TQMap<TQString, uint> groupIds;
bool m_dirty;
StructTreeTag *top;
- QValueList<StructTreeTag*> groups;
+ TQValueList<StructTreeTag*> groups;
uint groupsCount;
bool topOpened;
- QValueList<bool> groupOpened;
+ TQValueList<bool> groupOpened;
- mutable QListViewItem* m_marker; //track that has the drag/drop marker under it
- QListViewItem* m_draggedItem;
-// mutable QWidget* m_thisWidget; // non const this hack for acceptDrag
+ mutable TQListViewItem* m_marker; //track that has the drag/drop marker under it
+ TQListViewItem* m_draggedItem;
+// mutable TQWidget* m_thisWidget; // non const this hack for acceptDrag
protected: // Protected methods
/** Do a reparse before showing. */
- virtual void showEvent(QShowEvent*);
+ virtual void showEvent(TQShowEvent*);
/** Clear the problem output when hiding. */
- virtual void hideEvent(QHideEvent*);
+ virtual void hideEvent(TQHideEvent*);
// drag functions
- virtual bool acceptDrag(QDropEvent* e) const;
+ virtual bool acceptDrag(TQDropEvent* e) const;
virtual void startDrag();
- virtual void contentsMousePressEvent(QMouseEvent* e);
+ virtual void contentsMousePressEvent(TQMouseEvent* e);
protected slots: // Protected slots
/** The treeview DTD has changed to id. */
void slotDTDChanged(int id);
- void slotMouseClickedVPL(int button, QListViewItem*, const QPoint&, int);
- virtual void slotDropped(QDropEvent* e, QListViewItem* parent, QListViewItem* after);
+ void slotMouseClickedVPL(int button, TQListViewItem*, const TQPoint&, int);
+ virtual void slotDropped(TQDropEvent* e, TQListViewItem* parent, TQListViewItem* after);
protected: // Protected attributes
Document *write;
- QTime *timer;
+ TQTime *timer;
};
#endif